==> ugene_50.0+dfsg.orig.tar.xz: ugene-50.0/src/corelibs/U2Algorithm/src/util_msaedit/highlighting_schemes/MsaHighlightingSchemeDisagreements.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include "MsaHighlightingScheme.h"

namespace U2 {

class MsaHighlightingSchemeDisagreements : public MsaHighlightingScheme {
    Q_OBJECT
public:
    MsaHighlightingSchemeDisagreements(QObject* parent, const MsaHighlightingSchemeFactory* factory, MsaObject* maObj);

    void process(const char refChar, char& seqChar, QColor& color, bool& hightlight, int refCharColumn, int refCharRow) const;
};

class U2ALGORITHM_EXPORT MsaHighlightingSchemeDisagreementsFactory : public MsaHighlightingSchemeFactory {
public:
    MsaHighlightingSchemeDisagreementsFactory(QObject* parent, const QString& id, const QString& name, const AlphabetFlags& supportedAlphabets);

    MsaHighlightingScheme* create(QObject* parent, MsaObject* maObj) const;
};

}  // namespace U2

==> ugene_51.0+dfsg.orig.tar.xz: ugene-51.0/src/corelibs/U2Algorithm/src/util_msaedit/highlighting_schemes/MsaHighlightingSchemeDisagreements.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include "MsaHighlightingScheme.h"

namespace U2 {

class MsaHighlightingSchemeDisagreements : public MsaHighlightingScheme {
    Q_OBJECT
public:
    MsaHighlightingSchemeDisagreements(QObject* parent, const MsaHighlightingSchemeFactory* factory, MsaObject* maObj);

    void process(const char refChar, char& seqChar, QColor& color, bool& hightlight, int refCharColumn, int refCharRow) const override;
};

class U2ALGORITHM_EXPORT MsaHighlightingSchemeDisagreementsFactory : public MsaHighlightingSchemeFactory {
public:
    MsaHighlightingSchemeDisagreementsFactory(QObject* parent, const QString& id, const QString& name, const AlphabetFlags& supportedAlphabets);

    MsaHighlightingScheme* create(QObject* parent, MsaObject* maObj) const override;
};

}  // namespace U2
